# -*- coding: utf-8 -*-
# setup_zisraw.py

"""Zisraw module setuptools script."""

import re

from setuptools import setup

with open('czifile/czifile.py') as fh:
    code = fh.read()

version = re.search(r"__version__ = '(.*?)'", code).groups()[0]

setup(
    name='zisraw',
    version=version,
    description='The zisraw package is deprecated. '
                'Please use the czifile package instead.',
    author='Christoph Gohlke',
    author_email='cgohlke@uci.edu',
    url='https://www.lfd.uci.edu/~gohlke/',
    license='BSD',
    py_modules=['zisraw'],
    install_requires=['czifile'],
    platforms=['any'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        ],
)



# -*- coding: utf-8 -*-
# zisraw.py

"""Proxy module for the czifile package."""

from czifile.czifile import __doc__, __all__, __version__  # noqa
from czifile.czifile import czi2tif  # noqa
from czifile.czifile import *  # noqa
